import frameworkApi from '@/api/framework'
import storage from '@/framework/utils/storage'

const KEY_MENU_SELECTED = 'menu_selected'
const KEY_PROJECT_SELECTED = 'global_project_selected'
const KEY_PAGE_BRANDCRUMB = 'page_brandcrumb'

export default {
    namespaced: true,
    state: {
        sidebarClosed: false,
        sidebarSelected: '', // sidebar选中的选项
        userInfo: { username: 'admin' },
        permissions: { "system:role:delete": true, "system:role:create": true, "system:role:query": true, "system:role:setOpts": true },
        currentProjectId: null,
        projects: [{ name: '新华创新大厦', id: 'Pj1101080002' }],
        breadcrumb: []
    },
    getters: {
        sidebarClosed: state => state.sidebarClosed,
        sidebarSelected: state => {
            if (!state.pageSidebarSelected) {
                let menu = storage.get(KEY_MENU_SELECTED)
                if (menu) {
                    state.pageSidebarSelected = menu
                }
            }
            return state.pageSidebarSelected
        },
        userInfo: state => state.userInfo,
        permissions: state => state.permissions,
        projects: state => state.projects,
        currentProjectId: state => {
            if (!state.currentProjectId) {
                let pid = storage.get(KEY_PROJECT_SELECTED)
                if (pid) {
                    state.currentProjectId = pid
                }
            }
            return state.currentProjectId
        },
        breadcrumb: state => {
            if (!state.breadcrumb) {
                let arr = storage.get(KEY_PAGE_BRANDCRUMB)
                if (arr) {
                    state.breadcrumb = arr
                }
            }
            return state.breadcrumb
        }
    },
    mutations: {
        setSidebarClosed: (state, val) => (state.sidebarClosed = val),
        setSidebarSelected: (state, val) => {
            state.sidebarSelected = val
            storage.set(KEY_MENU_SELECTED, val)
        },
        setCurrentProjectId: (state, val) => {
            state.currentProjectId = val
            storage.set(KEY_PROJECT_SELECTED, val)
        }
    },
    actions: {
        loadUserInfo({ state }) {
            return new Promise((resolve, reject) => {
                frameworkApi.loadUserInfo().then(resp => {
                    console.log('api load user info ', resp)
                    if (resp.result == 'success') {
                        state.userInfo = { username: resp.username }
                        state.permissions = {}
                        if (resp.permissions) {
                            resp.permissions.forEach(p => (state.permissions[p] = true))
                        }
                        state.projects = []
                        if (resp.projects) {
                            resp.projects.forEach(proj =>
                                state.projects.push({
                                    id: proj.projId,
                                    name: proj.projLocalName
                                })
                            )
                        }
                    } else {
                        state.userInfo = null
                    }
                    resolve(resp)
                })
            })
        },
        setBreadcrumb: {
            root: true,
            handler({ state }, val) {
                state.breadcrumb = []
                state.breadcrumb = val
                storage.set(KEY_PAGE_BRANDCRUMB, val)
            }
        }
    }
}
